@@ -22,16 +22,23 @@
 #  MA 02110-1301, USA.
 #
 
-__all__ = ["utils", "dialogs", "icons", "keyboard"]
+__all__ = ["utils", "dialogs", "icons", "keyboard", "dir_picker", "list_dialog", "style_picker","LogCtrl"]
 
 __author__ = "Dominic Davis-Foster"
 __copyright__ = "Copyright 2019 Dominic Davis-Foster"
 
 __license__ = "LGPL"
-__version__ = "0.1.2"
+__version__ = "0.1.7"
 __email__ = "dominic@davis-foster.co.uk"
 
-from . import *
+from . import utils
+from . import dialogs
+from . import icons
+from . import keyboard
+from . import dir_picker
+from . import list_dialog
+from . import style_picker
+
 
 
 
